pub struct BuildahDriver;Trait Implementations
Sourceimpl BuildDriver for BuildahDriver
impl BuildDriver for BuildahDriver
Sourcefn pull(opts: PullOpts<'_>) -> Result<ContainerId>
fn pull(opts: PullOpts<'_>) -> Result<ContainerId>
Runs the pull logic for the driver Read more
Sourcefn manifest_create(opts: ManifestCreateOpts<'_>) -> Result<()>
fn manifest_create(opts: ManifestCreateOpts<'_>) -> Result<()>
Create a manifest containing all the built images. Read more
Sourcefn manifest_push(opts: ManifestPushOpts<'_>) -> Result<()>
fn manifest_push(opts: ManifestPushOpts<'_>) -> Result<()>
Pushes a manifest containing all the built images. Read more
Sourcefn build_tag_push(opts: BuildTagPushOpts<'_>) -> Result<Vec<String>>
fn build_tag_push(opts: BuildTagPushOpts<'_>) -> Result<Vec<String>>
Runs the logic for building, tagging, and pushing an image. Read more
Sourceimpl Debug for BuildahDriver
impl Debug for BuildahDriver
Sourceimpl DriverVersion for BuildahDriver
impl DriverVersion for BuildahDriver
Sourceconst VERSION_REQ: &'static str = ">=1.29"
const VERSION_REQ: &'static str = ">=1.29"
The version req string slice that follows
the semver standard https://semver.org/.
fn is_supported_version() -> bool
Sourceimpl ImageStorageDriver for BuildahDriver
impl ImageStorageDriver for BuildahDriver
Sourcefn remove_image(opts: RemoveImageOpts<'_>) -> Result<()>
fn remove_image(opts: RemoveImageOpts<'_>) -> Result<()>
Removes an image Read more