Driver

Struct Driver 

pub struct Driver;

Implementations

Source

impl Driver

pub fn init(args: DriverArgs)

Initializes the Strategy with user provided credentials.

If you want to take advantage of a user’s credentials, you will want to run init before trying to use any of the strategies.

Panics

Will panic if it is unable to initialize drivers.

pub fn get_build_id() -> Uuid

Gets the current build’s UUID

pub fn get_build_driver() -> BuildDriverType

pub fn get_signing_driver() -> SigningDriverType

pub fn get_run_driver() -> RunDriverType

pub fn get_ci_driver() -> CiDriverType

pub fn get_boot_driver() -> BootDriverType

pub fn get_os_version<'f1>() -> DriverGetOsVersionBuilder<'f1>

Retrieve the os_version for an image.

This gets cached for faster resolution if it’s required in another part of the program.

Errors

Will error if the image doesn’t have OS version info or we are unable to lock a mutex.

Panics

Panics if the mutex fails to lock.