PodmanDriver

Struct PodmanDriver 

pub struct PodmanDriver;

Implementations

Source

impl PodmanDriver

pub fn copy_image_to_root_store(image: &Reference) -> Result<()>

Copy an image from the user container store to the root container store for booting off of.

Errors

Will error if the image can’t be copied.