pub struct Driver;Implementations
Sourceimpl Driver
impl Driver
Sourcepub fn init(args: DriverArgs)
pub fn init(args: DriverArgs)
Initializes the Strategy with user provided credentials.
If you want to take advantage of a user’s credentials, you will want to run init before trying to use any of the strategies.
Panics
Will panic if it is unable to initialize drivers.
Sourcepub fn get_build_id() -> Uuid
pub fn get_build_id() -> Uuid
Gets the current build’s UUID
pub fn get_build_driver() -> BuildDriverType
pub fn get_signing_driver() -> SigningDriverType
pub fn get_run_driver() -> RunDriverType
pub fn get_ci_driver() -> CiDriverType
pub fn get_boot_driver() -> BootDriverType
Sourcepub fn get_os_version<'f1>() -> DriverGetOsVersionBuilder<'f1>
pub fn get_os_version<'f1>() -> DriverGetOsVersionBuilder<'f1>